@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: udp-send.pl,v 1.3.2.1 2006/06/04 13:23:13 gomor Exp $
+# $Id: udp-send.pl,v 1.3.2.2 2006/11/23 22:44:24 gomor Exp $
 #
 use strict;
 use warnings;
@@ -49,3 +49,6 @@ until ($Env->dump->timeout) {
       last;
    }
 }
+
+$Env->dump->stop;
+$Env->dump->clean;
