@@ -1,5 +1,5 @@
 #
-# $Id: Consts.pm,v 1.2.2.8 2006/11/12 18:10:19 gomor Exp $
+# $Id: Consts.pm,v 1.2.2.11 2006/11/15 19:28:13 gomor Exp $
 #
 package Net::Packet::Consts;
 use strict;
@@ -26,6 +26,7 @@ our %EXPORT_TAGS = (
       NP_DUMP_LINK_EN10MB
       NP_DUMP_LINK_RAW
       NP_DUMP_LINK_SLL
+      NP_DUMP_LINK_PPP
       NP_DUMP_MODE_OFFLINE
       NP_DUMP_MODE_ONLINE
       NP_DUMP_MODE_WRITER
@@ -51,6 +52,9 @@ our %EXPORT_TAGS = (
       NP_LAYER_LLC     
       NP_LAYER_PPPLCP
       NP_LAYER_CDP
+      NP_LAYER_STP
+      NP_LAYER_OSPF
+      NP_LAYER_IGMPv4
       NP_LAYER_N_2
       NP_LAYER_N_3
       NP_LAYER_N_4
@@ -105,6 +109,8 @@ our %EXPORT_TAGS = (
       NP_IPv4_PROTOCOL_UDP
       NP_IPv4_PROTOCOL_ICMPv4
       NP_IPv4_PROTOCOL_IPv6
+      NP_IPv4_PROTOCOL_OSPF
+      NP_IPv4_PROTOCOL_IGMPv4
       NP_IPv4_MORE_FRAGMENT
       NP_IPv4_DONT_FRAGMENT
       NP_IPv4_RESERVED_FRAGMENT
@@ -117,6 +123,8 @@ our %EXPORT_TAGS = (
    )],
    pppoe => [qw(
       NP_PPPoE_HDR_LEN
+      NP_PPPoE_PPP_PROTOCOL_IPv4
+      NP_PPPoE_PPP_PROTOCOL_PPPLCP
    )],
    ppp => [qw(
       NP_PPP_HDR_LEN
@@ -140,7 +148,7 @@ our %EXPORT_TAGS = (
       NP_CDP_HDR_LEN
       NP_CDP_TYPE_DEVICE_ID
       NP_CDP_TYPE_ADDRESSES
-      NP_CDP_TYPE_UNKNOWN_0003
+      NP_CDP_TYPE_PORT_ID
       NP_CDP_TYPE_CAPABILITIES
       NP_CDP_TYPE_SOFTWARE_VERSION
       NP_CDP_TYPE_PLATFORM
@@ -161,6 +169,30 @@ our %EXPORT_TAGS = (
       NP_CDP_TYPE_SYSTEM_OBJECT_ID
       NP_CDP_TYPE_UNKNOWN_0016
       NP_CDP_TYPE_LOCATION
+      NP_CDP_ADDRESS_PROTOCOL_TYPE_NLPID
+      NP_CDP_ADDRESS_PROTOCOL_LENGTH_NLPID
+      NP_CDP_ADDRESS_PROTOCOL_IP
+      NP_CDP_ADDRESS_ADDRESS_LENGTH_IP
+   )],
+   stp => [qw(
+      NP_STP_HDR_LEN
+      NP_STP_PROTOCOL_IDENTIFIER_STP
+   )],
+   ospf => [qw(
+      NP_OSPF_HDR_LEN
+      NP_OSPF_AUTH_TYPE_NULL
+   )],
+   igmpv4 => [qw(
+      NP_IGMPv4_HDR_LEN
+      NP_IGMPv4_v1_TYPE_QUERY
+      NP_IGMPv4_v1_TYPE_REPORT
+      NP_IGMPv4_v2_TYPE_QUERY
+      NP_IGMPv4_v2_TYPE_QUERY_v1
+      NP_IGMPv4_v2_TYPE_REPORT
+      NP_IGMPv4_v2_TYPE_LEAVE_GROUP
+      NP_IGMPv4_GROUP_ADDRESS_NO_HOSTS    
+      NP_IGMPv4_GROUP_ADDRESS_ALL_HOSTS   
+      NP_IGMPv4_GROUP_ADDRESS_ALL_ROUTERS 
    )],
    tcp => [qw(
       NP_TCP_HDR_LEN
@@ -224,6 +256,9 @@ our @EXPORT_OK = (
    @{$EXPORT_TAGS{llc}},
    @{$EXPORT_TAGS{ppplcp}},
    @{$EXPORT_TAGS{cdp}},
+   @{$EXPORT_TAGS{stp}},
+   @{$EXPORT_TAGS{ospf}},
+   @{$EXPORT_TAGS{igmpv4}},
 );
 
 use constant NP_DESC_IPPROTO_IP     => 0;
@@ -239,6 +274,7 @@ use constant NP_DESC_L4             => 'DescL4';
 
 use constant NP_DUMP_LINK_NULL   => 0;
 use constant NP_DUMP_LINK_EN10MB => 1;
+use constant NP_DUMP_LINK_PPP    => 9;
 use constant NP_DUMP_LINK_RAW    => 12;
 use constant NP_DUMP_LINK_SLL    => 113;
 use constant NP_DUMP_MODE_ONLINE  => 0;
@@ -265,6 +301,9 @@ use constant NP_LAYER_PPP     => 'PPP';
 use constant NP_LAYER_LLC     => 'LLC';
 use constant NP_LAYER_PPPLCP  => 'PPPLCP';
 use constant NP_LAYER_CDP     => 'CDP';
+use constant NP_LAYER_STP     => 'STP';
+use constant NP_LAYER_OSPF    => 'OSPF';
+use constant NP_LAYER_IGMPv4  => 'IGMPv4';
 use constant NP_LAYER_N_2       => 'L2';
 use constant NP_LAYER_N_3       => 'L3';
 use constant NP_LAYER_N_4       => 'L4';
@@ -313,6 +352,8 @@ use constant NP_IPv4_PROTOCOL_ICMPv4   => 1;
 use constant NP_IPv4_PROTOCOL_TCP      => 6;
 use constant NP_IPv4_PROTOCOL_UDP      => 17;
 use constant NP_IPv4_PROTOCOL_IPv6     => 41;
+use constant NP_IPv4_PROTOCOL_OSPF     => 0x59;
+use constant NP_IPv4_PROTOCOL_IGMPv4   => 0x02;
 use constant NP_IPv4_MORE_FRAGMENT     => 1;
 use constant NP_IPv4_DONT_FRAGMENT     => 2;
 use constant NP_IPv4_RESERVED_FRAGMENT => 4;
@@ -322,12 +363,14 @@ use constant NP_IPv6_V6           => 6;
 use constant NP_IPv6_PROTOCOL_TCP => NP_IPv4_PROTOCOL_TCP();
 use constant NP_IPv6_PROTOCOL_UDP => NP_IPv4_PROTOCOL_UDP();
 
-use constant NP_PPPoE_HDR_LEN => 6;
-
-use constant NP_PPP_HDR_LEN         => 2;
+use constant NP_PPP_HDR_LEN         => 4;
 use constant NP_PPP_PROTOCOL_IPv4   => 0x0021;
 use constant NP_PPP_PROTOCOL_PPPLCP => 0xc021;
 
+use constant NP_PPPoE_HDR_LEN => 8;
+use constant NP_PPPoE_PPP_PROTOCOL_IPv4   => NP_PPP_PROTOCOL_IPv4;
+use constant NP_PPPoE_PPP_PROTOCOL_PPPLCP => NP_PPP_PROTOCOL_PPPLCP;
+
 use constant NP_LLC_HDR_LEN   => 8;
 use constant NP_LLC_OUI_CISCO => 0x00000c;
 use constant NP_LLC_PID_CDP   => 0x2000;
@@ -342,7 +385,7 @@ use constant NP_PPPLCP_CODE_ECHO_REPLY   => 0x0a;
 use constant NP_CDP_HDR_LEN                    => 4;
 use constant NP_CDP_TYPE_DEVICE_ID             => 0x0001;
 use constant NP_CDP_TYPE_ADDRESSES             => 0x0002;
-use constant NP_CDP_TYPE_UNKNOWN_0003          => 0x0003;
+use constant NP_CDP_TYPE_PORT_ID               => 0x0003;
 use constant NP_CDP_TYPE_CAPABILITIES          => 0x0004;
 use constant NP_CDP_TYPE_SOFTWARE_VERSION      => 0x0005;
 use constant NP_CDP_TYPE_PLATFORM              => 0x0006;
@@ -363,6 +406,27 @@ use constant NP_CDP_TYPE_SYSTEM_NAME           => 0x0014;
 use constant NP_CDP_TYPE_SYSTEM_OBJECT_ID      => 0x0015;
 use constant NP_CDP_TYPE_UNKNOWN_0016          => 0x0016;
 use constant NP_CDP_TYPE_LOCATION              => 0x0017;
+use constant NP_CDP_ADDRESS_PROTOCOL_TYPE_NLPID   => 0x01;
+use constant NP_CDP_ADDRESS_PROTOCOL_LENGTH_NLPID => 0x01;
+use constant NP_CDP_ADDRESS_PROTOCOL_IP           => 0xcc;
+use constant NP_CDP_ADDRESS_ADDRESS_LENGTH_IP     => 0x0004;
+
+use constant NP_STP_HDR_LEN                 => 42;
+use constant NP_STP_PROTOCOL_IDENTIFIER_STP => 0x0000;
+
+use constant NP_OSPF_HDR_LEN        => 24;
+use constant NP_OSPF_AUTH_TYPE_NULL => 0x0000;
+
+use constant NP_IGMPv4_HDR_LEN             => 8;
+use constant NP_IGMPv4_v1_TYPE_QUERY       => 1;
+use constant NP_IGMPv4_v1_TYPE_REPORT      => 2;
+use constant NP_IGMPv4_v2_TYPE_QUERY       => 0x11;
+use constant NP_IGMPv4_v2_TYPE_QUERY_v1    => 0x12;
+use constant NP_IGMPv4_v2_TYPE_REPORT      => 0x16;
+use constant NP_IGMPv4_v2_TYPE_LEAVE_GROUP => 0x17;
+use constant NP_IGMPv4_GROUP_ADDRESS_NO_HOSTS    => '224.0.0.0';
+use constant NP_IGMPv4_GROUP_ADDRESS_ALL_HOSTS   => '224.0.0.1';
+use constant NP_IGMPv4_GROUP_ADDRESS_ALL_ROUTERS => '224.0.0.2';
 
 use constant NP_TCP_HDR_LEN  => 20;
 use constant NP_TCP_FLAG_FIN => 0x01;
